@@ -1,4 +1,4 @@
-static const char rcsid[] = "$Id: approve.c,v 1.146 2004/10/22 00:26:17 will Exp $";
+static const char rcsid[] = "$Id: approve.c,v 1.150 2007/03/07 15:00:16 will Exp $";
 
 /* The code should compile with either ANSI C or K&R compilers. */
 
@@ -52,14 +52,16 @@ int verbosity;		/* HELP_BASIC, HELP_FULL, or HELP_FACTS */
 	return "";
 
     /* Open the super.tab file we are supposed to process, and then... */
-    if (!(currfile = file_open(NULL, superfile, 0, NULL, NULL)))
+    if (!(currfile = file_open(NULL, superfile, 0, NULL, NULL))) {
 	return NULL;
+    }
     /* ...immediately chain-open the common super file (if it exists), so
      * that it is always invoked by all commands (super.tab or per-user),
      * and require it to be root-owned.
      */
-    if (!(currfile = file_open(currfile, superfile_init, 1, 0, NULL)))
+    if (!(currfile = file_open(currfile, superfile_init, 1, 0, NULL))) {
 	return NULL;
+    }
 
     for (localinfo.progs.commandfound=NULL, currfile->line = 1;
 	(buf=fillbuffer(currfile->fp, &indentok, &currfile->nl)) ||
@@ -75,12 +77,13 @@ int verbosity;		/* HELP_BASIC, HELP_FULL, or HELP_FACTS */
 	error_nl = currfile->nl;
 
 	if (!indentok) {
-	     Error(0, 0, "%t\n\tformat error in super.tab file:\n\
+	    Error(0, 0, "%t\n\tformat error in super.tab file:\n\
 \tContinued line not indented.\n");
-	    if (check_syntax)
+	    if (check_syntax) {
 		continue;
-	    else
+	    } else {
 		return NULL;
+	    }
 	}
 
 
@@ -92,16 +95,18 @@ int verbosity;		/* HELP_BASIC, HELP_FULL, or HELP_FACTS */
 	if (bbuf != buf) {
 	    Error(0, 0, "%t\n\tformat error in super(1) file: \n\
 \tNon-comments must begin in column 1.\n");
-	    if (check_syntax)
+	    if (check_syntax) {
 		continue;
-	    else
+	    } else {
 		return NULL;
+	    }
 	}
 
 	/* Clean out embedded comments, whitespace-newline-whitespace. */
 	buf = clean_buf(buf, NULL);
-	if (!buf)
+	if (!buf) {
 	    return NULL;
+	}
 	if (debug) {
 	    fprintf(stderr,
 	    "==============================================================\n");
@@ -111,22 +116,25 @@ int verbosity;		/* HELP_BASIC, HELP_FULL, or HELP_FACTS */
 	/* Do variable expansion */
 	buf = do_variables(buf);
 	if (!buf) {
-	    if (check_syntax)
+	    if (check_syntax) {
 		continue;
-	    else
+	    } else {
 		return NULL;
+	    }
 	}
 
 	/* Initialize localinfo */
 	if (handle_option(NULL, NULL, 0) == -1) {
-	    if (check_syntax)
+	    if (check_syntax) {
 		continue;
-	    else
+	    } else {
 		return NULL;
+	    }
 	}
 
 	if (check_syntax) {
-	    parseline(0, 1, buf, usrcmd);
+	    if (parseline(0, 1, buf, usrcmd) == -1) {
+	    }
 
 	} else if (givehelp) {
 	    switch (parseline(1, 0, buf, usrcmd)) {
@@ -565,8 +573,12 @@ char *cond_or_opt_wd;	/* First word to process; rest we get with strqtokS */
 		s = invert ? cond_or_opt_wd+1 : cond_or_opt_wd;
 
 		/* Do brace globbing */
-		if ((i=globbraces(s, 1, &glob)) != 0)
+		if (balancedbraces(s) != 0) {
+		    return Error(0, 0, "%tUnbalanced braces in `%s'.\n", s);
+		}
+		if ((i=globbraces(s, 1, &glob)) != 0) {
 		    return Error(0, 0, "%tMissing `%c'.\n", i);
+		}
 
 		if (InsertUserList(s, glob,
 		    &localinfo.userpats, &localinfo.origtext, invert) == -1)
