@@ -1,4 +1,4 @@
-static const char rcsid[] = "$Id: super.c,v 1.592 2004/10/21 21:35:25 will Exp $";
+static const char rcsid[] = "$Id: super.c,v 1.596 2007/03/07 16:58:13 will Exp $";
 /* The code should compile with either ANSI C or K&R compilers. */
 
 /*
@@ -307,7 +307,7 @@ so it can't check passwords on modern Unix systems.\n\n");
 	/* Test if we simply print variables, then bail out. */
 	if (printvars) {
 	    printf("Builtin variables:\n");
-	    hprint(print_variable);
+	    hprint(HS_VARS, print_variable);
 	    exit(0);
 	}
     } else {
@@ -369,10 +369,16 @@ so it can't check passwords on modern Unix systems.\n\n");
 	exit(0);
 
     /* Check for permission to execute, and change uid/gid as necessary */
+    error_counter = 0;	/* incremented by Error() */
     if ((path = approve(cmd, givehelp, verbosity)) == NULL) {
 	return 1;
     } else if (*path == '\0') {
-	return 0;
+	/* shouldn't try to execute anything */
+	if (check_syntax) {
+	    return (error_counter) ? 1 : 0;
+	} else {
+	    return 0;
+	}
     }
 
     /* Get the arglist for the command, and null-terminate cmd if not
