@@ -60,8 +60,12 @@
 #define HELP_USAGE	3	/* Print usage only, no per-cmd help */
 
 #ifndef SUPERFILE
+#ifdef SUPERDIR
+#define SUPERFILE SUPERDIR "/super.tab"
+#else
 #define SUPERFILE "/usr/local/lib/super.tab"
 #endif
+#endif
 
 #ifndef PERUSER_SUPERFILE
 #define PERUSER_SUPERFILE ".supertab"
@@ -165,6 +169,7 @@ void *memset P__(( void *s, int c, size_t n ));
     extern char superfile_init[];	/* The super.init file. */
     extern int it_came_from_cmdline;	/* Set by -F/-T/-U/-G flags */
     extern int using_user_supertab;	/* !0 means using a user's .supertab */
+    extern int error_counter;		/* incremented by Error() */
 
 /* The following external variables control the Error() routine.
  * They are modified at various points by super(), to give detailed control
@@ -493,6 +498,7 @@ int	add_variable P__(( char *varname, char *vardefn ));
 void	anchor P__(( char *in, char *out ));
 char*	approve P__((char *usrcmd, int givehelp, int verbose));
 char*	auth_name P__(( void ));
+int	balancedbraces P__(( char *s ));
 char ** blkdup P__((char **blk));
 int	blkfree P__((char **av0));
 char ** Blkdup P__((char *str, char **blk));
